@@ -1,3 +1,4 @@
+import time
 from typing import Tuple, Dict, Any
 from web3 import HTTPProvider, Web3
 from eth_utils.abi import function_abi_to_4byte_selector, collapse_if_tuple
@@ -179,17 +180,28 @@ def record_transaction(redis_client, user_id: str, chain: str, tx_hash: str) ->
     redis_client.rpush(key, tx_hash)
     print(f"Recorded transaction {tx_hash} on {chain} for user {user_id}")
 
-def mpc_transfer(default_address, destination, chain_raw, token_raw, token_address, amount):
+def mpc_transfer(default_address: WalletAddress, destination, chain_raw, token_raw, token_address, amount):
+    tx_hash = None
     try:
         if chain_raw == 'base' and token_raw == 'usdc':
             transfer = default_address.transfer(amount, 'usdc', destination, gasless=True)
-            transfer.wait()
+            try:
+                transfer.wait()
+            except Exception as e:
+                print(f"Transfer error: {e}", flush=True)
+
+            while str(transfer.status) not in ['complete','failed']:
+                print(f"Waiting for transaction status: {transfer.status}")
+                transfer.reload()
+                tx_hash = str(transfer.transaction_hash)
+                time.sleep(1)
             if str(transfer.status) == 'complete':
                 status = 200
                 transfer_status = 1
                 print(f"Transfer complete: {transfer.transaction_hash}")
                 print(f"Transfer successfully landed on-chain: {transfer.transaction_link}")
             else:
+                print(f"Error: {transfer.status}")
                 status = 500
                 transfer_status = 0
                 print(f"Transfer failed on-chain: {transfer.transaction_link}")
@@ -217,6 +229,7 @@ def mpc_transfer(default_address, destination, chain_raw, token_raw, token_addre
             }
             return info
     except Exception as e:
+        print(f"Exception occurred: {e}, Tx hash: {tx_hash}", flush=True)
         info = {
             "content": f"{e}",
             "code": 500
@@ -284,7 +297,7 @@ def transfer(receiver: str, amount: float, step: any, chain: str = "base", token
         token_address = w3.to_checksum_address(token_address)
     print(f"token address: {token_address}", flush=True)
     
-    print(f"w3: {w3}", flush=True)
+    # print(f"w3: {w3}", flush=True)
 
     if run_mode.lower() == 'auto':
         return handle_auto_transfer(w3, eth_w3, mpc_address, executor, receiver, amount, token_address, spender_address, sender_address, control_contract, private_key, redis_client, chain_raw, token_raw, blockchain_explore, executor_balance)
@@ -308,7 +321,7 @@ def handle_auto_transfer(w3: Web3, eth_w3, mpc_address, executor, receiver, amou
             to = w3.to_checksum_address(receiver_address)
             executor = w3.to_checksum_address(executor)
 
-            print(f"to: {to}, executor: {executor}")
+            print(f"to: {to}, executor: {executor}", flush=True)
             info = mpc_transfer(mpc_address, to, chain_raw, token_raw, token_address, amount)
             if info['code'] != 200:
                 increase_token_amount(redis_client, executor, chain_raw, token_raw, amount_to_transfer)
